; <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
; Nom du projet : Dev-Module
; Nom du fichier : DevModule - Options.pb
; Version du fichier : 0.9.0
; Programmation : OK
; Programm par : Guillaume Saumure
; Alias : StarBootics
; Courriel : gsaumure@cgocable.ca
; Date : 03-10-2014
; Mise  jour : 24-05-2018
; Code PureBasic : V5.62
; Plateforme : Windows, Linux, MacOS X
; <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

DeclareModule Options
  
  Declare Initialize()
  Declare WritePrefs(P_GroupName.s)
  Declare ReadPrefs(P_GroupName.s)
  Declare RefreshEditors(Flag.b, OtherEditor.l = -1)
  Declare To_GUI()
  Declare AskSavePath()
  Declare AskNewFont()
  Declare AskNewColor(ColorID)
  Declare Reset()
  Declare GadgetLinking(GadgetID, Flag)
  Declare.s GetProjectSavePath()
  Declare GetFrontColor()
  Declare GetBackColor()
  
EndDeclareModule

Module Options
  
  ; <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
  ; <<<<< Dclaration des Structures <<<<<

  Structure Secondary

    ProjectPathGadget.l
    FontNameGadget.l
    FontSizeGadget.l
    FontHandle.i
    FrontColorGadget.l
    BackColorGadget.l
    EditorGadget.l[3]

  EndStructure

  Structure Instance

    ProjectSavePath.s
    FontName.s
    FontSize.b
    FrontColor.l
    BackColor.l

  EndStructure

  Global Secondary.Secondary
  Global Instance.Instance
  
  ; <<<<<<<<<<<<<<<<<<<<<<<<<<<<
  ; <<<<< Les observateurs <<<<<
  
  Procedure GetFrontColor()
  
     ProcedureReturn Instance\FrontColor
  EndProcedure
  
  Procedure GetBackColor()
  
     ProcedureReturn Instance\BackColor
  EndProcedure
  
  Procedure.s GetProjectSavePath()

    ProcedureReturn Instance\ProjectSavePath
  EndProcedure
  
  ; <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
  ; <<<<< L'oprateur Initialize <<<<<

  Procedure Initialize()
    
    CompilerSelect #PB_Compiler_OS
        
      CompilerCase #PB_OS_Windows
        Instance\FontName = "Lucida Console"
        
      CompilerCase #PB_OS_Linux
        Instance\FontName = "monofur"
        
      CompilerCase #PB_OS_MacOS
        Instance\FontName = "Monaco"
        
    CompilerEndSelect
    
    Instance\ProjectSavePath = GetHomeDirectory()
    Instance\FontSize = 14
    Instance\FrontColor = $ffffff
    Instance\BackColor = $000000
    
  EndProcedure
  
  Procedure WritePrefs(P_GroupName.s)
    
    PreferenceGroup(P_GroupName)
    
    WritePreferenceString("ProjectSavePath", Instance\ProjectSavePath)
    WritePreferenceString("FontName", Instance\FontName)
    WritePreferenceLong("FontSize", Instance\FontSize)
    WritePreferenceString("FrontColor", FormatColor::DoIt(Instance\FrontColor))
    WritePreferenceString("BackColor", FormatColor::DoIt(Instance\BackColor))
    
  EndProcedure
  
  Procedure ReadPrefs(P_GroupName.s)
    
    PreferenceGroup(P_GroupName)
    
    Instance\ProjectSavePath = ReadPreferenceString("ProjectSavePath", Instance\ProjectSavePath)
    Instance\FontName = ReadPreferenceString("FontName", Instance\FontName)
    Instance\FontSize = ReadPreferenceLong("FontSize", Instance\FontSize)
    Instance\FrontColor = FormatColor::UndoIt(ReadPreferenceString("FrontColor", FormatColor::DoIt(Instance\FrontColor)))
    Instance\BackColor = FormatColor::UndoIt(ReadPreferenceString("BackColor", FormatColor::DoIt(Instance\BackColor)))
    
  EndProcedure
  
  Procedure RefreshEditors(Flag.b, OtherEditor.l = -1)
    
    If OtherEditor = -1
      
      Select Flag
          
        Case 0
          
          For EditorID = 0 To 2
            SetGadgetColor(Secondary\EditorGadget[EditorID], #PB_Gadget_FrontColor, Instance\FrontColor)
            SetGadgetColor(Secondary\EditorGadget[EditorID], #PB_Gadget_BackColor, Instance\BackColor)
          Next
          
        Case 1
          
          If IsFont(Secondary\FontHandle)
            FreeFont(Secondary\FontHandle)
          EndIf
          
          Secondary\FontHandle = LoadFont(#PB_Any, Instance\FontName, Instance\FontSize)
          
          If IsFont(Secondary\FontHandle)
            For EditorID = 0 To 2
              SetGadgetFont(Secondary\EditorGadget[EditorID], FontID(Secondary\FontHandle))
            Next
          EndIf
          
        Case 2
          
          For EditorID = 0 To 2
            SetGadgetColor(Secondary\EditorGadget[EditorID], #PB_Gadget_FrontColor, Instance\FrontColor)
            SetGadgetColor(Secondary\EditorGadget[EditorID], #PB_Gadget_BackColor, Instance\BackColor)
          Next
          
          If IsFont(Secondary\FontHandle)
            FreeFont(Secondary\FontHandle)
          EndIf
          
          Secondary\FontHandle = LoadFont(#PB_Any, Instance\FontName, Instance\FontSize)
          
          If IsFont(Secondary\FontHandle)
            For EditorID = 0 To 2
              SetGadgetFont(Secondary\EditorGadget[EditorID], FontID(Secondary\FontHandle))
            Next
          EndIf
          
      EndSelect
      
    Else
      
      SetGadgetColor(OtherEditor, #PB_Gadget_FrontColor, Instance\FrontColor)
      SetGadgetColor(OtherEditor, #PB_Gadget_BackColor, Instance\BackColor) 
      SetGadgetFont(OtherEditor, FontID(Secondary\FontHandle))
      
    EndIf
    
  EndProcedure
  
  Procedure To_GUI()
    
    SetGadgetText(Secondary\ProjectPathGadget, Instance\ProjectSavePath)
    SetGadgetText(Secondary\FontNameGadget, Instance\FontName)
    SetGadgetText(Secondary\FontSizeGadget, Str(Instance\FontSize))
    SetGadgetColor(Secondary\FrontColorGadget, #PB_Gadget_BackColor, Instance\FrontColor)
    SetGadgetColor(Secondary\BackColorGadget, #PB_Gadget_BackColor, Instance\BackColor)
    RefreshEditors(2)
    
  EndProcedure
  
  Procedure AskSavePath()
    
    NewPath.s = PathRequester(Language::Message("Select folder"), Instance\ProjectSavePath)
    
    If NewPath <> ""
      Instance\ProjectSavePath = NewPath
      SetGadgetText(Secondary\ProjectPathGadget, Instance\ProjectSavePath)
    EndIf 
    
  EndProcedure
  
  Procedure AskNewFont()
    
    If FontRequester(Instance\FontName, Instance\FontSize, #PB_FontRequester_Effects)
      Instance\FontName = SelectedFontName()
      Instance\FontSize = SelectedFontSize()
      SetGadgetText(Secondary\FontNameGadget, Instance\FontName)
      SetGadgetText(Secondary\FontSizeGadget, Str(Instance\FontSize))
      RefreshEditors(1)
    EndIf 

  EndProcedure 
  
  Procedure AskNewColor(ColorID)
    
    Select ColorID
        
      Case 0 
        
        NewColor = ColorRequester(Instance\FrontColor)
        
        If NewColor > -1
          Instance\FrontColor = NewColor
          ColorPreview::CurrentColor(Secondary\FrontColorGadget, Instance\FrontColor)
          RefreshEditors(0)
        EndIf 
        
      Case 1
        
        NewColor = ColorRequester(Instance\BackColor)
        
        If NewColor > -1
          Instance\BackColor = NewColor
          ColorPreview::CurrentColor(Secondary\BackColorGadget, Instance\BackColor)
          RefreshEditors(0)
        EndIf 
        
    EndSelect
    
  EndProcedure 
  
  Procedure Reset()
    
    Instance\ProjectSavePath = ""
    Instance\FontName = ""
    Instance\FontSize = 0
    Instance\FrontColor = 0
    Instance\BackColor = 0
    
    Secondary\ProjectPathGadget = 0
    Secondary\FontNameGadget = 0
    Secondary\FontSizeGadget = 0
    
    If IsFont(Secondary\FontHandle)
      FreeFont(Secondary\FontHandle)
    EndIf
    
    Secondary\FrontColorGadget = 0
    Secondary\BackColorGadget = 0
    
    For EditorID = 0 To 2
      Secondary\EditorGadget[EditorID] = 0
    Next
    
  EndProcedure
  
  Procedure GadgetLinking(GadgetID, Flag)
    
    Select Flag
        
      Case 0
        Secondary\ProjectPathGadget = GadgetID
        
      Case 1
        Secondary\FontNameGadget = GadgetID
        
      Case 2
        Secondary\FontSizeGadget = GadgetID
        
      Case 3
        Secondary\FrontColorGadget = GadgetID
        
      Case 4
        Secondary\BackColorGadget = GadgetID
        
      Case 5
        Secondary\EditorGadget[0] = GadgetID
        
      Case 6
        Secondary\EditorGadget[1] = GadgetID
        
      Case 7
        Secondary\EditorGadget[2] = GadgetID
                
    EndSelect

  EndProcedure

EndModule

; <<<<<<<<<<<<<<<<<<<<<<<<<<
; <<<<< FIN DU FICHIER <<<<<
; <<<<<<<<<<<<<<<<<<<<<<<<<<
; IDE Options = PureBasic 5.62 (Linux - x64)
; Folding = P---
; EnableXP
; CompileSourceDirectory